
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListFilter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-filter'], 'items': [{'path': {'d': 'M2 5h20'}}, {'path': {'d': 'M6 12h12'}}, {'path': {'d': 'M9 19h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Laptop(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-laptop'], 'items': [{'path': {'d': 'M18 5a2 2 0 0 1 2 2v8.526a2 2 0 0 0 .212.897l1.068 2.127a1 1 0 0 1-.9 1.45H3.62a1 1 0 0 1-.9-1.45l1.068-2.127A2 2 0 0 0 4 15.526V7a2 2 0 0 1 2-2z'}}, {'path': {'d': 'M20.054 15.987H3.946'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TouchpadOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-touchpad-off'], 'items': [{'path': {'d': 'M12 20v-6'}}, {'path': {'d': 'M19.656 14H22'}}, {'path': {'d': 'M2 14h12'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M20 20H4a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2'}}, {'path': {'d': 'M9.656 4H20a2 2 0 0 1 2 2v10.344'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AirVent(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-air-vent'], 'items': [{'path': {'d': 'M18 17.5a2.5 2.5 0 1 1-4 2.03V12'}}, {'path': {'d': 'M6 12H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2h-2'}}, {'path': {'d': 'M6 8h12'}}, {'path': {'d': 'M6.6 15.572A2 2 0 1 0 10 17v-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MonitorCloud(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor-cloud'], 'items': [{'path': {'d': 'M11 13a3 3 0 1 1 2.83-4H14a2 2 0 0 1 0 4z'}}, {'path': {'d': 'M12 17v4'}}, {'path': {'d': 'M8 21h8'}}, {'rect': {'x': '2', 'y': '3', 'width': '20', 'height': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Gpu(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-gpu'], 'items': [{'path': {'d': 'M2 21V3'}}, {'path': {'d': 'M2 5h18a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2.26'}}, {'path': {'d': 'M7 17v3a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-3'}}, {'circle': {'cx': '16', 'cy': '11', 'r': '2'}}, {'circle': {'cx': '8', 'cy': '11', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Microwave(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-microwave'], 'items': [{'rect': {'width': '20', 'height': '15', 'x': '2', 'y': '4', 'rx': '2'}}, {'rect': {'width': '8', 'height': '7', 'x': '6', 'y': '8', 'rx': '1'}}, {'path': {'d': 'M18 8v7'}}, {'path': {'d': 'M6 19v2'}}, {'path': {'d': 'M18 19v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def WindArrowDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wind-arrow-down'], 'items': [{'path': {'d': 'M10 2v8'}}, {'path': {'d': 'M12.8 21.6A2 2 0 1 0 14 18H2'}}, {'path': {'d': 'M17.5 10a2.5 2.5 0 1 1 2 4H2'}}, {'path': {'d': 'm6 6 4 4 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleParking(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-parking'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M9 17V7h4a3 3 0 0 1 0 6H9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RectangleCircle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rectangle-circle'], 'items': [{'path': {'d': 'M14 4v16H3a1 1 0 0 1-1-1V5a1 1 0 0 1 1-1z'}}, {'circle': {'cx': '14', 'cy': '12', 'r': '8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Minimize2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-minimize-2'], 'items': [{'path': {'d': 'm14 10 7-7'}}, {'path': {'d': 'M20 10h-6V4'}}, {'path': {'d': 'm3 21 7-7'}}, {'path': {'d': 'M4 14h6v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DoorClosedLocked(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-door-closed-locked'], 'items': [{'path': {'d': 'M10 12h.01'}}, {'path': {'d': 'M18 9V6a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v14'}}, {'path': {'d': 'M2 20h8'}}, {'path': {'d': 'M20 17v-2a2 2 0 1 0-4 0v2'}}, {'rect': {'x': '14', 'y': '17', 'width': '8', 'height': '5', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquarePen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-pen'], 'items': [{'path': {'d': 'M12 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7'}}, {'path': {'d': 'M18.375 2.625a1 1 0 0 1 3 3l-9.013 9.014a2 2 0 0 1-.853.505l-2.873.84a.5.5 0 0 1-.62-.62l.84-2.873a2 2 0 0 1 .506-.852z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
